@@ -18,6 +18,13 @@ def compare_pvector(v, other, operator):
     return operator(v.tolist(), other.tolist() if isinstance(other, PVector) else other)
 
 
+def _index_or_slice(index, stop):
+    if stop is None:
+        return index
+
+    return slice(index, stop)
+
+
 class PythonPVector(object):
     """
     Support structure for PVector that implements structural sharing for vectors using a trie.
@@ -225,6 +232,20 @@ class PythonPVector(object):
 
             return ret
 
+        def delete(self, index, stop=None):
+            del self[_index_or_slice(index, stop)]
+            return self
+
+        def __delitem__(self, key):
+            if self._orig_pvector:
+                # All structural sharing bets are off, base evolver on _extra_tail only
+                l = self._orig_pvector.tolist()
+                l.extend(self._extra_tail)
+                self._reset(_EMPTY_PVECTOR)
+                self._extra_tail = l
+
+            del self._extra_tail[key]
+
         def persistent(self):
             result = self._orig_pvector
             if self.is_dirty():
@@ -380,6 +401,12 @@ class PythonPVector(object):
     def count(self, value):
         return self.tolist().count(value)
 
+    def delete(self, index, stop=None):
+        l = self.tolist()
+        del l[_index_or_slice(index, stop)]
+        return _EMPTY_PVECTOR.extend(l)
+
+
 @six.add_metaclass(ABCMeta)
 class PVector(object):
     """
@@ -618,6 +645,18 @@ class PVector(object):
         True
         """
 
+    @abstractmethod
+    def delete(self, index, stop=None):
+        """
+        Delete a portion of the vector by index or range.
+
+        >>> v1 = v(1, 2, 3, 4, 5)
+        >>> v1.delete(1)
+        pvector([1, 3, 4, 5])
+        >>> v1.delete(1, 3)
+        pvector([1, 4, 5])
+        """
+
 _EMPTY_PVECTOR = PythonPVector(0, SHIFT, [], [])
 PVector.register(PythonPVector)
 Sequence.register(PVector)
@@ -653,4 +692,4 @@ def v(*elements):
     >>> v1
     pvector([1, 2, 3])
     """
-    return pvector(elements)
\ No newline at end of file
+    return pvector(elements)
